#
# spec file for package bibtool
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bibtool
Version:        2.68
Release:        2.4
Summary:        Tool for Manipulating BibTeX Databases
License:        CC-BY-SA-3.0 AND GPL-1.0-or-later
URL:            http://www.gerd-neugebauer.de/software/TeX/BibTool/index.en.html
Source0:        http://www.gerd-neugebauer.de/software/TeX/BibTool/BibTool-%{version}.tar.gz
Source1:        http://www.gerd-neugebauer.de/software/TeX/BibTool/BibTool-%{version}.tar.gz.asc
Source2:        %{name}.keyring
Patch1:         bibtool-use-system-regex.patch
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
BibTool is a tool for manipulating BibTeX databases. BibTeX provides a means to
integrate citations into LaTeX documents. BibTool allows the manipulation of
BibTeX files which goes beyond the possibilities - and intentions - of BibTeX.

%prep
%setup -q -n BibTool
# %patch -P 1 -p1

%build
%configure
make %{?_smp_mflags} all

%install
make INSTALLPREFIX=%{buildroot} install install-man

%files
%defattr(-,root,root,-)
%doc COPYING README.md
%attr(0644,root,root) %{_mandir}/man1/bibtool.1%{ext_man}
%{_bindir}/bibtool
%{_libdir}/BibTool

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN (all patches
  disabled, scripted change).
* Mon Jan 29 2024 jun wang <jgwang@suse.com>
- Update to version 2.68
  * Handling of extracting by aux file improved.
  * Record extended by attribute lineno.This attribute carries
    the line number of the initiating @.
  * The format of the error messages has been slightly
    streamlined. Double spaces are avoided; two colons in one
    message are avoided.
  * The format of the messages of check_rule include file and
    line number.
  * Warning for double fields added.
  * The empty output file is used to signal that the output
    should be suppressed.
  * The resources check.warning.rule and check.error.rule have
    been introduced to allow semantic checks to be classified
    as warning or error.
  * The behaviour of the resource check.double has been
    generalized. The requirement that double entries to be
    adjacent has been dropped. This has the impact that the
    processing is slightly slower.
  * New resource file unique.field introduced. With this
    resource it is possible to specify additional unique
    constraints for fields. If different records have the same
    value for one of those fields then a warning is issued.
  * Static library renamed from libbib.a to libbibtool.a.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Mon Aug 15 2016 mpluskal@suse.com
- Drop -doc subpackage as building it is getting more and more
  difficult
* Sun Feb  7 2016 mpluskal@suse.com
- Update to 2.36
  * Combined rewrite and delete bug fixed.
  * Minor improvements for the distribution.
  * README renamed to README.md to comply with the conventions of
    the GitHub repository.
* Thu Nov 26 2015 mpluskal@suse.com
- Update to 2.61
  * New resource rename.field introduced to conditionally rename a
    field.
  * Duplicate file doc/bibtool.tex in the distribution tar ball
    eliminated.
* Wed Jul 15 2015 cfarrell@suse.com
- license update: GPL-1.0+ and CC-BY-SA-3.0
  Various .sty files are CC-BY-SA-3.0 licensed
* Sat Jul 11 2015 mpluskal@suse.com
- Update to 2.60
  * The field name and other symbols may start with any allowed
    character.
  * Non-alpha characters at the beginning are treated as warining
    only.
- Use url for source
- Add gpg signature
- Small cleanups with spec-cleaner
* Tue Aug 26 2014 gber@opensuse.org
- update to version 2.57
  - Segfault in deTeX fixed.
  - Compiler warnings silenced.
  - Disambiguating numbers adapted to fit to documentation.
  - Configuration of regex fixed to work on Linux.
  - Documentation typos fixed.
  - Signed characters fro translation tables changed to unsigned.
  - Autoconf configuration improved.
- fix URL
- remove support for < 12.3
* Sat Aug 18 2012 gber@opensuse.org
- fix dependencies for oepnSUSE > 12.2
* Wed May 16 2012 gber@opensuse.org
- update to version 2.55
  - library biblatex.rsc added; it contains capitalizations of
    fields used in bibL TEX
  - fix for a misbehaviour when selecting entries according to an
    aux file with deeply nested @strings
* Tue Mar 13 2012 gber@opensuse.org
- update to version 2.54
  - command line parameter -V documented
  - resource key.make.alias added to create new @ALIAS records for
    any newly generated key
  - resource apply.alias added to expand the @ALIAS records
  - resource apply.include added to expand the @INCLUDE records
  - resource apply.modify added to expand the @MODIFY records
  - error message for -o without parameter added
  - fixed @ALIAS and @INCLUDE records not being printed
  - in tex.define spaces before the = are ignored instead of
    leading to unwanted definitions
  - the prepared makefiles for various operating systems missed an
    entry for crossref.[cho]
  - typo in help text and copyright year fixed
- do not make example scripts in order to prevent unwanted
  dependency-generation
- move examples to -doc subpackage and package the changelog
- removed obsolete bibtool-fix-libkpathsea-detection.patch and
  bibtool-honor-cflags.patch
* Thu Dec 22 2011 gber@opensuse.org
- spdx.org conforming license string
- added build dependency on automake
* Sat Apr 16 2011 gber@opensuse.org
- added bibtool-fix-libkpathsea-detection.patch and build with
  libkpathsea
* Sun Apr  3 2011 gber@opensuse.org
- initial packaging
